@@ -4,6 +4,7 @@ The given file contains the class to refer to the tag entity
 from quartic_sdk.core.entities.base import Base
 import quartic_sdk.utilities.constants as Constants
 from quartic_sdk.core.iterators.tag_data_iterator import TagDataIterator
+from quartic_sdk.utilities.exceptions import IncorrectTagParameterException,IncorrectWavelengthParamException
 
 
 class Tag(Base):
@@ -19,6 +20,24 @@ class Tag(Base):
         "tag_process_type": Constants.PROCESS_VARIABLE_TYPES,
         "category": Constants.INTELLIGENCE_CATEGORIES
     }
+    @staticmethod
+    def raise_exception_for_wavelegths(wavelengths):
+        """
+        Validate wavelengths passed for a spectral tag. Schema as following
+        {"wavelengths" : ['1460000.0','1460001.0]}
+        :param wavelengths: dict containing key as 'wavelengths' and value as list of wavelengths
+        """
+        assert isinstance(wavelengths, dict), "Wavelengths must be a dict"
+        
+        if not wavelengths.get('wavelengths'):
+            raise IncorrectWavelengthParamException(
+                'Invalid Wavelengths: "wavelengths" key required in dict'
+            )
+        elif not isinstance(wavelengths.get("wavelengths"), list):
+            raise IncorrectWavelengthParamException(
+                'Invalid Wavelengths: Wavelength values must be passed in a list '
+            )
+
 
     def __repr__(self):
         """
@@ -30,20 +49,24 @@ class Tag(Base):
             self,
             start_time,
             stop_time,
-            granularity=0,
+            sampling_ratio=1,
             return_type=Constants.RETURN_PANDAS,
             batch_size=Constants.DEFAULT_PAGE_LIMIT_ROWS,
+            wavelengths = {},
             transformations=[]):
         """
         Get the data for the given tag between the start_time and the stop_time
-        for the given granularity
-
+        for the given sampling_ratio
         :param start_time: (epoch) Start_time for getting data
         :param stop_time: (epoch) Stop_time for getting data
-        :param granularity: Granularity of the data
+        :param sampling_ratio: sampling_ratio of the data
         :param return_type: The param decides whether the data after querying will be
             json(when value is "json") or pandas dataframe(when value is "pd"). By default,
             it takes the value as "json"
+        :param wavelengths: dict containing list of wavelengths(string) as value with key "wavelengths"
+            Used for getting data for a spectral tag for specified wavelengths. 
+            An example value here is:
+            {"wavelengths:['1460000.0','1460001.0']}   
         :param transformations: Refers to the list of transformations. It supports either
             interpolation or aggregation, depending upon which, we pass the value of this
             dictionary. If `transformation_type` is "aggregation", an optional key can be
@@ -61,11 +84,14 @@ class Tag(Base):
                 "aggregation_dict": {"3": "max"},
                 "aggregation_timestamp": "last",
             }]
-
         :return: (DataIterator) DataIterator object which can be iterated to get the data
             between the given duration
         """
-        from quartic_sdk.core.entity_helpers.entity_list import EntityList
+        from quartic_sdk.core.entity_helpers.entity_list import EntityList       
+        if wavelengths and self.tag_data_type !=  Constants.TAG_DATA_TYPES[6]:
+            raise IncorrectTagParameterException( "Invalid parameters : Wavelengths are only supported with spectral tag type")                    
+        if wavelengths:
+            Tag.raise_exception_for_wavelegths(wavelengths)
         return TagDataIterator.create_tag_data_iterator(
             EntityList(
                 Constants.TAG_ENTITY,
@@ -73,9 +99,10 @@ class Tag(Base):
             start_time,
             stop_time,
             self.api_helper,
-            granularity,
+            sampling_ratio,
             return_type,
             batch_size,
+            wavelengths,
             transformations)
 
     def __getattribute__(self, name):
